## $Id: viewlets.py 9872 2013-01-12 07:10:56Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from waeup.kofa.students.viewlets import (
    FileDisplay, FileUpload, Image)
from waeup.kofa.students.browser import ExportPDFClearanceSlipPage
from waeup.kofa.students.viewlets import (
    AddPreviousPaymentActionButton, AddBalancePaymentActionButton)

from kofacustom.nigeria.interfaces import MessageFactory as _


class AddPreviousPaymentActionButton(AddPreviousPaymentActionButton):

    @property
    def target_url(self):
        return ''

class AddBalancePaymentActionButton(AddBalancePaymentActionButton):

    @property
    def target_url(self):
        return ''

# Accepted by Institution

class AcceptedByInstitutionDisplay(FileDisplay):
    """Accepted by Institution display viewlet.
    """
    grok.order(19)
    label = _(u'Accepted by Institution')
    title = _(u'Accepted by Institution')
    download_name = u'acc_inst'

class AcceptedByInstitutionSlip(AcceptedByInstitutionDisplay):
    grok.view(ExportPDFClearanceSlipPage)

class AcceptedByInstitutionUpload(FileUpload):
    """Accepted by Institution upload viewlet.
    """
    grok.order(19)
    label = _(u'Accepted by Institution')
    title = _(u'Accepted by Institution Scan')
    mus = 1024 * 150
    download_name = u'acc_inst'

class AcceptedByInstitutionImage(Image):
    """Renders Accepted by Institution scan.
    """
    grok.name('acc_inst')
    download_name = u'acc_inst'

# Credential

class CredentialDisplay(FileDisplay):
    """Credential display viewlet.
    """
    grok.order(20)
    label = _(u'Credential')
    title = _(u'Credential')
    download_name = u'cred'

class CredentialSlip(CredentialDisplay):
    grok.view(ExportPDFClearanceSlipPage)

class CredentialUpload(FileUpload):
    """Credential upload viewlet.
    """
    grok.order(20)
    label = _(u'Credential')
    title = _(u'Credential')
    mus = 1024 * 150
    download_name = u'cred'

class CredentialImage(Image):
    """Credential scan.
    """
    grok.name('cred')
    download_name = u'cred'

# Student Signature

class StudentSignatureDisplay(FileDisplay):
    """Student Signature display viewlet.
    """
    grok.order(21)
    label = _(u'Student Signature')
    title = _(u'Student Signature')
    download_name = u'signature'

class StudentSignatureSlip(StudentSignatureDisplay):
    grok.view(ExportPDFClearanceSlipPage)

class StudentSignatureUpload(FileUpload):
    """Student Signature upload viewlet.
    """
    grok.order(21)
    label = _(u'Student Signature')
    title = _(u'Student Signature')
    mus = 1024 * 150
    download_name = u'signature'

class StudentSignatureImage(Image):
    """Student Signature scan.
    """
    grok.name('signature')
    download_name = u'signature'

# JAMB Letter

class JAMBLetterDisplay(FileDisplay):
    """JAMB Letter display viewlet.
    """
    grok.order(23)
    label = _(u'JAMB Letter')
    title = _(u'JAMB Letter')
    download_name = u'jamb_let'

class JAMBLetterSlip(JAMBLetterDisplay):
    grok.view(ExportPDFClearanceSlipPage)

class JAMBLetterUpload(FileUpload):
    """JAMB Letter upload viewlet.
    """
    grok.order(23)
    label = _(u'JAMB Letter')
    title = _(u'JAMB Letter')
    mus = 1024 * 150
    download_name = u'jamb_let'

class JAMBLetterImage(Image):
    """JAMB Letter scan.
    """
    grok.name('jamb_let')
    download_name = u'jamb_let'

# JAMB Slip

class JAMBSlipDisplay(FileDisplay):
    """JAMB Slip display viewlet.
    """
    grok.order(24)
    label = _(u'JAMB Slip')
    title = _(u'JAMB Slip')
    download_name = u'jamb_slip'

class JAMBSlipSlip(JAMBSlipDisplay):
    grok.view(ExportPDFClearanceSlipPage)

class JAMBSlipUpload(FileUpload):
    """JAMB Slip upload viewlet.
    """
    grok.order(24)
    label = _(u'JAMB Slip')
    title = _(u'JAMB Slip')
    mus = 1024 * 150
    download_name = u'jamb_slip'

class JAMBSlipImage(Image):
    """JAMB Slip scan.
    """
    grok.name('jamb_slip')
    download_name = u'jamb_slip'

# Age Declaration

class AgeDeclarationDisplay(FileDisplay):
    """Age Declaration display viewlet.
    """
    grok.order(25)
    label = _(u'Age Declaration')
    title = _(u'Age Declaration')
    download_name = u'age_dec'

class AgeDeclarationSlip(AgeDeclarationDisplay):
    grok.view(ExportPDFClearanceSlipPage)

class AgeDeclarationUpload(FileUpload):
    """Age Declaration upload viewlet.
    """
    grok.order(25)
    label = _(u'Age Declaration')
    title = _(u'Age Declaration')
    mus = 1024 * 150
    download_name = u'age_dec'

class AgeDeclarationImage(Image):
    """Age Declaration scan.
    """
    grok.name('age_dec')
    download_name = u'age_dec'